/* FreeTDS - Library of routines accessing Sybase and Microsoft databases
 * Copyright (C) 1998-1999  Brian Bruns
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _tdsversion_h_
#define _tdsversion_h_

/* $Id: 9640daf619734147e3b5ff6a1dad56ad305ffa51 $ */

#define TDS_VERSION_NO "freetds v1.2.19"

#define TDS_VERSION_MAJOR 1
#define TDS_VERSION_MINOR 2
#define TDS_VERSION_SUBVERSION 19
#define TDS_VERSION_BUILD_NUMBER 469

#endif
